#define QT_FEATURE_shared 1
#define QT_FEATURE_cross_compile -1
#define QT_FEATURE_framework -1
#define QT_FEATURE_rpath 1
#define QT_FEATURE_simulator_and_device -1
#define QT_FEATURE_thread 1
#define QT_FEATURE_appstore_compliant -1
#define QT_FEATURE_debug_and_release -1
#define QT_FEATURE_build_all -1
#define QT_FEATURE_c__11 1
#define QT_FEATURE_c__14 1
#define QT_FEATURE_c__17 1
#define QT_FEATURE_c__1z 1
#define QT_FEATURE_c__2a -1
#define QT_FEATURE_c__2b -1
#define QT_FEATURE_c99 1
#define QT_FEATURE_c11 1
#define QT_FEATURE_future 1
#define QT_FEATURE_concurrent 1
#define QT_FEATURE_pkg_config 1
#define QT_FEATURE_force_asserts -1
#define QT_LARGEFILE_SUPPORT 64
#define QT_VISIBILITY_AVAILABLE true
#define QT_FEATURE_separate_debug_info -1
#define QT_FEATURE_signaling_nan 1
#define QT_FEATURE_static -1
#define QT_VERSION_STR "5.15.14"
#define QT_VERSION_MAJOR 5
#define QT_VERSION_MINOR 15
#define QT_VERSION_PATCH 14
